@@ -1,11 +1,13 @@
+import os
+
 __author__    = 'Steve Nicholes'
 __copyright__ = 'Copyright (C) 2015 Steve Nicholes'
 __license__   = 'GPLv3'
-__version__   = '0.2.4'
+with open(os.path.join(os.path.dirname(__file__), r'version.txt'), 'r') as input:
+    __version__   = input.readlines()[0]
 __url__       = 'https://github.com/endangeredoxen/pywebify'
 
 from pywebify.template import *
 from pywebify.pywebify import *
-
 from . import webpage
 from webpage import Webpage
